EntryType

Enum EntryType 

pub enum EntryType {
Show 13 variants Regular, Link, Symlink, Char, Block, Directory, Fifo, Continuous, GNULongName, GNULongLink, GNUSparse, XGlobalHeader, XHeader, // some variants omitted
}
Indicate for the type of file described by a header.

Each Header has an entry_type method returning an instance of this type which can be used to inspect what the header is describing. A non-exhaustive enum representing the possible entry types

Variants



Regular

Regular file

Hard link

Symbolic link



Char

Character device



Block

Block device



Directory

Directory



Fifo

Named pipe (fifo)



Continuous

Implementation-defined ‘high-performance’ type, treated as regular file



GNULongName

GNU extension - long file name

GNU extension - long link name (link target)



GNUSparse

GNU extension - sparse file



XGlobalHeader

Global extended header



XHeader

Extended Header

Implementations

Source

impl EntryType

pub fn new(byte: u8) -> EntryType

Creates a new entry type from a raw byte.

Note that the other named constructors of entry type may be more appropriate to create a file type from.

pub fn as_byte(&self) -> u8

Returns the raw underlying byte that this entry type represents.

pub fn file() -> EntryType

Creates a new entry type representing a regular file.

Creates a new entry type representing a hard link.

Creates a new entry type representing a symlink.

pub fn character_special() -> EntryType

Creates a new entry type representing a character special device.

pub fn block_special() -> EntryType

Creates a new entry type representing a block special device.

pub fn dir() -> EntryType

Creates a new entry type representing a directory.

pub fn fifo() -> EntryType

Creates a new entry type representing a FIFO.

pub fn contiguous() -> EntryType

Creates a new entry type representing a contiguous file.

pub fn is_file(&self) -> bool

Returns whether this type represents a regular file.

Returns whether this type represents a hard link.

Returns whether this type represents a symlink.

pub fn is_character_special(&self) -> bool

Returns whether this type represents a character special device.

pub fn is_block_special(&self) -> bool

Returns whether this type represents a block special device.

pub fn is_dir(&self) -> bool

Returns whether this type represents a directory.

pub fn is_fifo(&self) -> bool

Returns whether this type represents a FIFO.

pub fn is_contiguous(&self) -> bool

Returns whether this type represents a contiguous file.

pub fn is_gnu_longname(&self) -> bool

Returns whether this type represents a GNU long name header.

pub fn is_gnu_sparse(&self) -> bool

Returns whether this type represents a GNU sparse header.

Returns whether this type represents a GNU long link header.

pub fn is_pax_global_extensions(&self) -> bool

Returns whether this type represents PAX global extensions, that should affect all following entries. For more, see PAX.

pub fn is_pax_local_extensions(&self) -> bool

Returns whether this type represents PAX local extensions; these only affect the current entry. For more, see PAX.